Get HIT- and/or Assignment-level ReviewPolicy Results for a HIT
GetReviewResultsForHIT(hit, assignment = NULL, policy.level = NULL,
retrieve.results = TRUE, retrieve.actions = TRUE,
verbose = getOption('MTurkR.verbose'), ...)A character string containing a HITId.
An optional character string containing an AssignmentId. If specified, only results pertaining to that assignment will be returned.
Either HIT or Assignment. If omitted, the default behavior is to retrieve all data for both policy levels.
Optionally retrieve ReviewResults. Default is TRUE.
Optionally retrieve ReviewActions. Default is TRUE.
Optionally print the results of the API request to the standard output. Default is taken from getOption('MturkR.verbose').
Additional arguments passed to request.
A list containing up to four named dataframes, depending on what ReviewPolicy (or ReviewPolicies) were attached to the HIT: AssignmentReviewResult, AssignmentReviewAction, HITReviewResult, HITReviewAction.
A simple function to return the results of a ReviewPolicy. This is intended only for advanced users, who should reference MTurk documentation for further information.
reviewresults is an alias.
# NOT RUN {
GetReviewResultsForHIT()
# }
Run the code above in your browser using DataLab